@@ -198,7 +198,7 @@ sxed_confirmed_cancel (GncSxEditorDialog2 *sxed)
         const char *sx_changed_msg =
             _( "This Scheduled Transaction has changed; are you "
                "sure you want to cancel?" );
-        if (!gnc_verify_dialog (sxed->dialog, FALSE, "%s", sx_changed_msg))
+        if (!gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE, "%s", sx_changed_msg))
         {
             return FALSE;
         }
@@ -636,7 +636,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
 				     _( "Couldn't parse credit formula for "
 					"split \"%s\"." ),
 				     xaccSplitGetMemo( s ) );
-		    gnc_error_dialog( GTK_WIDGET(sxed->dialog), "%s",
+                    gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s",
 				      errStr->str );
 		    g_string_free( errStr, TRUE );
 
@@ -658,7 +658,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
 				     _( "Couldn't parse debit formula for "
 					"split \"%s\"." ),
 				     xaccSplitGetMemo( s ) );
-		    gnc_error_dialog( GTK_WIDGET(sxed->dialog), "%s",
+                    gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s",
 				      (gchar*)errStr->str );
 		    g_string_free( errStr, TRUE );
 
@@ -686,7 +686,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
         g_hash_table_destroy (txns);
 
         if (unbalanceable
-                && !gnc_verify_dialog (sxed->dialog, FALSE,
+                && !gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE,
                                        "%s",
                                        _("The Scheduled Transaction Editor "
                                          "cannot automatically balance "
@@ -710,7 +710,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
         {
             const char *sx_has_no_name_msg =
                 _("Please name the Scheduled Transaction.");
-            gnc_error_dialog (sxed->dialog, "%s", sx_has_no_name_msg);
+            gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s", sx_has_no_name_msg);
             g_free (name);
             return FALSE;
 
@@ -740,7 +740,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
                    "name \"%s\" already exists. "
                    "Are you sure you want to name "
                    "this one the same?");
-            if (!gnc_verify_dialog (sxed->dialog, FALSE,
+            if (!gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE,
                                       sx_has_existing_name_msg,
                                       name))
             {
@@ -763,7 +763,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
 
         if (((ttVarCount > 0) || multi_commodity) && autocreateState)
         {
-            gnc_warning_dialog (sxed->dialog, "%s",
+            gnc_warning_dialog (GTK_WINDOW (sxed->dialog), "%s",
                                _("Scheduled Transactions with variables "
                                  "cannot be automatically created."));
             return FALSE;
@@ -773,7 +773,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
          * only valid if there's actually a transaction to create. */
         if (autocreateState && splitCount == 0)
         {
-            gnc_warning_dialog (sxed->dialog, "%s",
+            gnc_warning_dialog (GTK_WINDOW (sxed->dialog), "%s",
                                _("Scheduled Transactions without a template "
                                  "transaction cannot be automatically created."));
             return FALSE;
@@ -790,7 +790,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
         {
             const char *sx_end_spec_msg =
                 _("Please provide a valid end selection.");
-            gnc_error_dialog (sxed->dialog, "%s", sx_end_spec_msg);
+            gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s", sx_end_spec_msg);
             return FALSE;
         }
 
@@ -808,7 +808,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
             {
                 const char *sx_occur_count_zero_msg =
                     _("There must be some number of occurrences.");
-                gnc_error_dialog (sxed->dialog, "%s",
+                gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s",
                                   sx_occur_count_zero_msg);
                 return FALSE;
             }
@@ -819,7 +819,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
                     _("The number of remaining occurrences "
                        "(%d) is greater than the number of "
                        "total occurrences (%d).");
-                gnc_error_dialog (sxed->dialog,
+                gnc_error_dialog (GTK_WINDOW (sxed->dialog),
                                   sx_occur_counts_wrong_msg,
                                   rem, occur);
                 return FALSE;
@@ -851,7 +851,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
                 _("You have attempted to create a Scheduled "
                   "Transaction which will never run. Do you "
                   "really want to do this?");
-            if (!gnc_verify_dialog (sxed->dialog, FALSE,
+            if (!gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE,
                                    "%s", invalid_sx_check_msg))
                 return FALSE;
         }
@@ -1087,8 +1087,8 @@ sxed_delete_event (GtkWidget *widget, GdkEvent *event, gpointer ud)
  * Create the Schedule Editor Dialog *
  ************************************/
 GncSxEditorDialog2 *
-gnc_ui_scheduled_xaction_editor_dialog_create2 (SchedXaction *sx,
-					       gboolean newSX)
+gnc_ui_scheduled_xaction_editor_dialog_create2 (GtkWindow *parent, 
+    SchedXaction *sx, gboolean newSX)
 {
     GncSxEditorDialog2 *sxed;
     GtkBuilder *builder;
@@ -1166,11 +1166,12 @@ gnc_ui_scheduled_xaction_editor_dialog_create2 (SchedXaction *sx,
     // Set the style context for this dialog so it can be easily manipulated with css
     gnc_widget_set_style_context (GTK_WIDGET(sxed->dialog), "GncSxEditorDialog");
 
+    gtk_window_set_transient_for (GTK_WINDOW (sxed->dialog), parent);
+
     /* Setup the end-date GNC widget */
     {
         GtkWidget *endDateBox = GTK_WIDGET(gtk_builder_get_object (builder, "editor_end_date_box"));
-        sxed->endDateEntry = GNC_DATE_EDIT (gnc_date_edit_new (gnc_time (NULL),
-							      FALSE, FALSE));
+        sxed->endDateEntry = GNC_DATE_EDIT (gnc_date_edit_new (gnc_time (NULL), FALSE, FALSE));
         gtk_widget_show (GTK_WIDGET (sxed->endDateEntry));
         g_signal_connect (sxed->endDateEntry, "date-changed",
                           G_CALLBACK (sxed_excal_update_adapt_cb), sxed);
@@ -1521,7 +1522,7 @@ gnc_sxed_reg_check_close (GncSxEditorDialog2 *sxed)
     if (dirty_trans == NULL)
         return;
 
-    if (gnc_verify_dialog (sxed->dialog, TRUE, "%s", message))
+    if (gnc_verify_dialog (GTK_WINDOW (sxed->dialog), TRUE, "%s", message))
     {
         /* Save the template transactions changes */
         xaccTransCommitEdit (dirty_trans);
@@ -1665,6 +1666,7 @@ typedef struct _acct_deletion_handler_data
 {
     GList *affected_sxes;
     GtkWidget *dialog;
+    GtkWindow *parent;
 } acct_deletion_handler_data;
 
 
@@ -1677,8 +1679,8 @@ _open_editors (GtkDialog *dialog, gint response_code, gpointer data)
         GList *sx_iter;
         for (sx_iter = adhd->affected_sxes; sx_iter; sx_iter = sx_iter->next)
         {
-            gnc_ui_scheduled_xaction_editor_dialog_create2 ((SchedXaction*)sx_iter->data,
-                    FALSE);
+            gnc_ui_scheduled_xaction_editor_dialog_create2 (GTK_WINDOW(adhd->parent),
+                (SchedXaction*)sx_iter->data, FALSE);
         }
     }
     g_list_free (adhd->affected_sxes);
@@ -1710,6 +1712,7 @@ _sx_engine_event_handler (QofInstance *ent, QofEventId event_type, gpointer user
         acct_deletion_handler_data *data;
         GtkBuilder *builder;
         GtkWidget *dialog;
+        GtkWindow *parent;
         GtkListStore *name_list;
         GtkTreeView *list;
         GtkTreeViewColumn *name_column;
@@ -1719,6 +1722,9 @@ _sx_engine_event_handler (QofInstance *ent, QofEventId event_type, gpointer user
         gnc_builder_add_from_file (builder, "dialog-sx.glade", "account_deletion_dialog");
 
         dialog = GTK_WIDGET (gtk_builder_get_object (builder, "account_deletion_dialog"));
+        parent = gnc_ui_get_main_window (NULL);
+        
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), parent);
 
         list = GTK_TREE_VIEW (gtk_builder_get_object (builder, "sx_list"));
 
@@ -1727,6 +1733,7 @@ _sx_engine_event_handler (QofInstance *ent, QofEventId event_type, gpointer user
 
         data = (acct_deletion_handler_data*)g_new0 (acct_deletion_handler_data, 1);
         data->dialog = dialog;
+        data->parent = parent;
         data->affected_sxes = affected_sxes;
         name_list = gtk_list_store_new (1, G_TYPE_STRING);
         for (sx_iter = affected_sxes; sx_iter != NULL; sx_iter = sx_iter->next)
