@@ -49,7 +49,6 @@
 (define-module (gnucash report fancy-invoice))
 
 (use-modules (srfi srfi-1))
-(use-modules (gnucash printf))
 (use-modules (gnucash gnc-module))
 (use-modules (gnucash gettext))
 
@@ -174,7 +173,7 @@
 
     (if (date-col column-vector)
         (addto! row-contents
-                (gnc-print-date (gncEntryGetDate entry))))
+                (qof-print-date (gncEntryGetDate entry))))
 
     (if (description-col column-vector)
         (addto! row-contents
@@ -455,7 +454,7 @@
 
 	(if (date-col used-columns)
 	    (addto! row
-		    (gnc-print-date (gnc-transaction-get-date-posted t))))
+		    (qof-print-date (xaccTransGetDate t))))
 
 	(if (description-col used-columns)
 	    (addto! row (_ "Payment, thank you")))
@@ -636,10 +635,10 @@
     (gnc:html-table-append-row!
      table
      (list
-      (string-expand (gnc:owner-get-address-dep owner) #\newline "<br>")))
+      (string-expand (gnc:owner-get-address-dep owner) #\newline "<br/>")))
     (gnc:html-table-append-row!
      table
-     (list "<br>"))
+     (list "<br/>"))
     (for-each
      (lambda (order)
        (let* ((reference (gncOrderGetReference order)))
@@ -663,9 +662,9 @@
     ;; for the invoice date/due date fields
     ;; I could have taken the format from the report options, but... ;)
     (string-expand (strftime (gnc-default-strftime-date-format)
-                             (gnc-localtime (car date)))
+                             (gnc-localtime date))
                    #\space "&nbsp;")
-    ;;(string-expand (gnc-print-date date) #\space "&nbsp;")
+    ;;(string-expand (qof-print-date date) #\space "&nbsp;")
     )))
 
 (define (make-date-table)
@@ -723,7 +722,7 @@
 	'attribute (list "align" "right")
 	'attribute (list "width" "33%"))
     (gnc:html-table-append-row!
-     table (list (string-expand (string-append (if addy addy "") (if id (string-append "\n" id) "")) #\newline "<br>")
+     table (list (string-expand (string-append (if addy addy "") (if id (string-append "\n" id) "")) #\newline "<br/>")
 		 (string-expand
 		  (string-append (if phone
 				     (string-append (_ "Phone:") " " phone)
@@ -731,7 +730,7 @@
 				 (if fax (string-append (if phone "\n" "")
 							(_ "Fax:") " " fax)
 				     ""))
-		  #\newline "<br>" )
+		  #\newline "<br/>" )
 		 (if url (string-append (_ "Web:") " " url) "")))
 
 ;; oli-custom - I didn't want today's date on the invoice.
@@ -740,7 +739,7 @@
 ;;    (gnc:html-table-append-row! table (list
 ;;				       (strftime
 ;;					date-format
-;;					(gnc-localtime (car (gnc:get-today))))))
+;;					(gnc-localtime (gnc:get-today)))))
     table))
 
 (define (make-break! document)
@@ -857,28 +856,28 @@
 	   'attribute (list "cellpadding" 0)
 	   'attribute (list "width" "100%"))
 
-	  (set! date-object (let ((date-table #f)
-		(post-date (gncInvoiceGetDatePosted invoice))
-		(due-date (gncInvoiceGetDateDue invoice)))
-
-	    (if (not (equal? post-date (cons 0 0)))
-		(begin
+          (set! date-object
+            (if (gncInvoiceIsPosted invoice)
+                (let ((date-table #f)
+                      (post-date (gncInvoiceGetDatePosted invoice))
+                      (due-date (gncInvoiceGetDateDue invoice)))
 		  (set! date-table (make-date-table))
-		  ;; oli-custom - moved invoice number here
 		  (gnc:html-table-append-row!
-		   date-table (list (sprintf #f (_ "%s&nbsp;#") title) (gncInvoiceGetID invoice)))
-                  ;; Translators: The first %s below is "Invoice" or
+                  ;; Translators: ~a below is "Invoice" or "Bill" or even the
+                  ;; custom title from the options. The next column contains
+                  ;; the number of the document.
+                  date-table (list (format #f (_ "~a&nbsp;#") title) (gncInvoiceGetID invoice)))
+                  ;; Translators: The first ~a below is "Invoice" or
                   ;; "Bill" or even the custom title from the
                   ;; options. This string sucks for i18n, but I don't
                   ;; have a better solution right now without breaking
                   ;; other people's invoices.
-		  (make-date-row! date-table (sprintf #f (_ "%s&nbsp;Date") title) post-date date-format)
-		  (make-date-row! date-table (_ "Due&nbsp;Date") due-date date-format)
+		  (make-date-row! date-table (format #f (_ "~a&nbsp;Date") title) post-date date-format)
+		  (make-date-row! date-table (_ "Due Date") due-date date-format)
 		  date-table)
 		(gnc:make-html-text
-		  ;; oli-custom - FIXME: I have a feeling I broke a
-		 ;; translation by not using string-expand for &nbsp;
-		  (string-append title "<br>" (_ "Invoice in progress..."))))))
+                 (string-append title "<br/>"
+                                (_ "Invoice in progress...")))))
 
 	  (gnc:html-table-append-row!
 	  	helper-table
@@ -911,7 +910,7 @@
 		       (gnc:make-html-text
 			(string-append
 			 (_ "Reference") ":&nbsp;"
-			 (string-expand billing-id #\newline "<br>"))))
+			 (string-expand billing-id #\newline "<br/>"))))
 		      (make-break! document)))))
 
 	  (if (opt-val "Display" "Billing Terms")
@@ -923,7 +922,7 @@
 		     (gnc:make-html-text
 		      (string-append
 		       (_ "Terms") ":&nbsp;"
-		       (string-expand terms #\newline "<br>")))))))
+		       (string-expand terms #\newline "<br/>")))))))
 
 	  (make-break! document)
 
@@ -949,7 +948,7 @@
 		 document
 		 (gnc:make-html-text
 		  (string-append name-str  ":&nbsp;"
-		  (string-expand name #\newline "<br>")))))))
+		  (string-expand name #\newline "<br/>")))))))
 
 	  (make-break! document)
 
@@ -961,13 +960,13 @@
 		 document
 		 (gnc:make-html-text
 		  (string-append contact-str  ":&nbsp;"
-		  (string-expand contact #\newline "<br>")))))))
+		  (string-expand contact #\newline "<br/>")))))))
 
 	  (gnc:html-document-add-object!
 	   document
 	   (gnc:make-html-text
 	    (gnc:html-markup-br)
-	    (string-expand (opt-val "Display" "Extra Notes") #\newline "<br>")
+	    (string-expand (opt-val "Display" "Extra Notes") #\newline "<br/>")
 	    (gnc:html-markup-br))))
 
 	; else
