@@ -29,7 +29,7 @@
 
 (use-modules (srfi srfi-1))
 (use-modules (gnucash gnc-module))
-(use-modules (gnucash main))        ; for gnc:debug
+(use-modules (gnucash utilities))        ; for gnc:debug
 (use-modules (gnucash gettext))
 
 (gnc:module-load "gnucash/report/report-system" 0)
@@ -73,20 +73,23 @@
   (cond ((eqv? owner-type GNC-OWNER-CUSTOMER) (N_ "Customer"))
         ((eqv? owner-type GNC-OWNER-EMPLOYEE) (N_ "Employee"))
         ;; FALL THROUGH
-        (else (N_ "Company")))) 
+        (else
+          (N_ "Company")))) 
 
 ;; Error strings in case there is no (valid) selection (translated)
 (define (invalid-selection-title-string owner-type)
   (cond ((eqv? owner-type GNC-OWNER-CUSTOMER) (_ "No valid customer selected."))
         ((eqv? owner-type GNC-OWNER-EMPLOYEE) (_ "No valid employee selected."))
         ;; FALL THROUGH
-        (else (_ "No valid company selected."))))
+        (else
+          (_ "No valid company selected."))))
 
 (define (invalid-selection-string owner-type)
   (cond ((eqv? owner-type GNC-OWNER-CUSTOMER) (_ "This report requires a customer to be selected."))
         ((eqv? owner-type GNC-OWNER-EMPLOYEE) (_ "This report requires a employee to be selected."))
         ;; FALL THROUGH
-        (else (_ "This report requires a company to be selected."))))
+        (else
+          (_ "This report requires a company to be selected."))))
 
 ;; Html formatted error message documents
 (define (gnc:html-make-no-owner-warning
@@ -111,7 +114,8 @@
   (cond ((eqv? owner-type GNC-OWNER-CUSTOMER) (_ "Customer"))
         ((eqv? owner-type GNC-OWNER-EMPLOYEE) (_ "Employee"))
         ;; FALL THROUGH
-        (else (_ "Vendor")))) 
+        (else
+          (_ "Vendor")))) 
 
 (define-macro (addto! alist element)
   `(set! ,alist (cons ,element ,alist)))
@@ -222,7 +226,7 @@
     (table (gnc:make-html-table)))
 
      (define (in-interval this-date current-bucket)
-      (gnc:timepair-lt this-date current-bucket))
+      (< this-date current-bucket))
 
      (define (find-bucket current-bucket bucket-intervals date)
       (begin
@@ -247,7 +251,7 @@
        (let* ((bal (gnc-lot-get-balance lot))
           (invoice (gncInvoiceGetInvoiceFromLot lot))
               (date (if (eq? date-type 'postdate)
-               (gncInvoiceGetDatePosted invoice) 
+               (gncInvoiceGetDatePostedTT invoice) 
                (gncInvoiceGetDateDue invoice)))
               )
          
@@ -283,12 +287,11 @@
 (define (make-row column-vector date due-date num type-str memo monetary credit debit sale tax)
   (let ((row-contents '()))
     (if (date-col column-vector)
-        (addto! row-contents (gnc-print-date date)))
+        (addto! row-contents (qof-print-date date)))
     (if (date-due-col column-vector)
         (addto! row-contents 
-         (if (and due-date
-              (not (equal? due-date (cons 0 0))))
-             (gnc-print-date due-date)
+         (if due-date
+             (qof-print-date due-date)
              "")))
     (if (num-col column-vector)
         (addto! row-contents num))
@@ -342,7 +345,7 @@
 (define (add-txn-row table txn acc column-vector odd-row? printed?
              reverse? start-date total)
   (let* ((type (xaccTransGetTxnType txn))
-     (date (gnc-transaction-get-date-posted txn))
+     (date (xaccTransGetDate txn))
      (due-date #f)
      (value (xaccTransGetAccountValue txn acc))
      (sale (gnc-numeric-zero))
@@ -369,7 +372,7 @@
    (if reverse?
     (set! value (gnc-numeric-neg value)))
 
-   (if (gnc:timepair-le start-date date)
+   (if (<= start-date date)
     (begin
       
       ; Adds 'balance' row if needed
@@ -378,7 +381,8 @@
       ; Now print out the invoice row
       (if (not (null? invoice))
         (begin
-          (set! due-date (gncInvoiceGetDateDue invoice))
+          (set! due-date (and (gncInvoiceIsPosted invoice)
+                              (gncInvoiceGetDateDue invoice)))
           (set! sale (gncInvoiceGetTotalSubtotal invoice))
           (set! tax (gncInvoiceGetTotalTax invoice))))
 
@@ -670,7 +674,7 @@
      guid QOF-QUERY-OR)
 
     (xaccQueryAddSingleAccountMatch q account QOF-QUERY-AND)
-    (xaccQueryAddDateMatchTS q #f end-date #t end-date QOF-QUERY-AND)
+    (xaccQueryAddDateMatchTT q #f end-date #t end-date QOF-QUERY-AND)
     (qof-query-set-book q (gnc-get-current-book))
     q))
 
@@ -698,7 +702,7 @@
    table
    (list
     (string-append label ":&nbsp;")
-    (string-expand (gnc-print-date date) #\space "&nbsp;"))))
+    (string-expand (qof-print-date date) #\space "&nbsp;"))))
 
 (define (make-date-table)
   (let ((table (gnc:make-html-table)))
@@ -731,7 +735,7 @@
     (gnc:html-table-append-row! table (list
                        (strftime
                     date-format
-                    (gnc-localtime (car (gnc:get-today))))))
+                    (gnc-localtime (gnc:get-today)))))
     table))
 
 (define (make-break! document)
@@ -750,20 +754,19 @@
      (orders '())
      (query (qof-query-create-for-splits))
      (account (opt-val owner-page acct-string))
-     (start-date (gnc:timepair-start-day-time 
+     (start-date (gnc:time64-start-day-time 
       (gnc:date-option-absolute-time
        (opt-val gnc:pagename-general optname-from-date))))
-     (end-date (gnc:timepair-end-day-time 
+     (end-date (gnc:time64-end-day-time 
                (gnc:date-option-absolute-time
                (opt-val gnc:pagename-general optname-to-date))))
      (book (gnc-account-get-book account))
-     (date-format (gnc:options-fancy-date book))
+     (date-format (if (not (null? book)) (gnc:options-fancy-date book)))
      (type (opt-val "__reg" "owner-type"))
      (owner-descr (owner-string type))
      (date-type (opt-val gnc:pagename-general optname-date-driver))
      (owner (opt-val owner-page owner-descr))
      (report-title (string-append (doctype-str type) " " (_ "Report"))))
-
     (if (not (gncOwnerIsValid owner))
      (gnc:html-document-add-object!
       document
@@ -817,9 +820,9 @@
           (string-append
            (_ "Date Range")
            ": "
-           (gnc-print-date start-date)
+           (qof-print-date start-date)
            " - "
-           (gnc-print-date end-date))))
+           (qof-print-date end-date))))
 
         (make-break! document)
 
