@@ -199,13 +199,6 @@
 (define (gnc:value->string value)
   (let ((result (call-with-output-string
                  (lambda (port) (write value port)))))
-       ;; Guile 1.8 has a bug that it serializes a space in a symbol to "\ "
-       ;; but can't deserialize this back to a symbol afterwards. Stripping the
-       ;; "\" appears to work around this (see gnucash bug  721654 which lead to this issue)
-       (cond-expand
-         (guile-2 )
-         (else (set! result (regexp-substitute/global #f "\\\\ " result 'pre " " 'post))))
-
        result))
 
 (define (gnc:make-string-option
@@ -569,13 +562,24 @@
          subtype
          relative-date-list)
   (define (date-legal date)
-    (and (pair? date) 
-         (or 
+    (and (pair? date)
+         (or
           (and (eq? 'relative (car date)) (symbol? (cdr date)))
-          (and (eq? 'absolute (car date)) 
-               (pair? (cdr date)) 
-               (exact? (cadr date)) 
-               (exact? (cddr date))))))
+          (and (eq? 'absolute (car date))
+               (or (and (pair? (cdr date))   ; we can still accept
+                        (exact? (cadr date)) ; old-style timepairs
+                        (exact? (cddr date)))
+                   (and (number? (cdr date))
+                        (exact? (cdr date))))))))
+  (define (maybe-convert-to-time64 date)
+    ;; compatibility shim. this is triggered only when date is type
+    ;; (cons 'absolute (cons sec nsec)) - we'll convert to
+    ;; (cons 'absolute sec). this shim must always be kept for gnucash
+    ;; to reload saved reports, or reload reports launched at startup,
+    ;; which had been saved as timepairs.
+    (if (pair? (cdr date))
+        (cons (car date) (cadr date))
+        date))
   (define (list-lookup list item)
     (cond
      ((null? list) #f)
@@ -589,7 +593,7 @@
      (lambda () value)
      (lambda (date)
        (if (date-legal date)
-           (set! value date)
+           (set! value (maybe-convert-to-time64 date))
            (gnc:error "Illegal date value set:" date)))
      default-getter
      (gnc:restore-form-generator value->string)
@@ -1688,32 +1692,50 @@
           (let ((option-hash (hash-ref section-hash name)))
             (if option-hash
                 option-hash
-                ; Option name was not found. Perhaps it was renamed ?
-                ; Let's try to map it to a known new name
+                ;; Option name was not found. Perhaps it was renamed ?
+                ;; Let's try to map it to a known new name.
+                ;; This list will try match names - if one is found
+                ;; the next item will describe a pair.
+                ;; (cons newsection newname)
+                ;; If newsection is #f then reuse previous section name.
+                ;;
+                ;; Please note the rename list currently supports renaming
+                ;; individual option names, or individual option names moved
+                ;; to another section. It does not currently support renaming
+                ;; whole sections.
                 (let* ((new-names-list (list
-                        "Accounts to include" "Accounts"
-                        "Exclude transactions between selected accounts?" "Exclude transactions between selected accounts"
-                        "Filter Accounts" "Filter By..."
-                        "Flatten list to depth limit?" "Flatten list to depth limit"
-                        "From" "Start Date"
-                        "Report Accounts" "Accounts"
-                        "Report Currency" "Report's currency"
-                        "Show Account Code?" "Show Account Code"
-                        "Show Full Account Name?" "Show Full Account Name"
-                        "Show Multi-currency Totals?" "Show Multi-currency Totals"
-                        "Show zero balance items?" "Show zero balance items"
-                        "Sign Reverses?" "Sign Reverses"
-                        "To" "End Date"
-                        "Use Full Account Name?" "Use Full Account Name"
-                        "Use Full Other Account Name?" "Use Full Other Account Name"
-                        "Void Transactions?" "Void Transactions"
-                        ))
+                                        "Accounts to include" (cons #f "Accounts")
+                                        "Exclude transactions between selected accounts?" (cons #f "Exclude transactions between selected accounts")
+                                        "Filter Accounts" (cons #f "Filter By...")
+                                        "Flatten list to depth limit?" (cons #f "Flatten list to depth limit")
+                                        "From" (cons #f "Start Date")
+                                        "Report Accounts" (cons #f "Accounts")
+                                        "Report Currency" (cons #f "Report's currency")
+                                        "Show Account Code?" (cons #f "Show Account Code")
+                                        "Show Full Account Name?" (cons #f "Show Full Account Name")
+                                        "Show Multi-currency Totals?" (cons #f "Show Multi-currency Totals")
+                                        "Show zero balance items?" (cons #f "Show zero balance items")
+                                        "Sign Reverses?" (cons #f "Sign Reverses")
+                                        "To" (cons #f "End Date")
+                                        "Use Full Account Name?" (cons #f "Use Full Account Name")
+                                        "Use Full Other Account Name?" (cons #f "Use Full Other Account Name")
+                                        "Void Transactions?" (cons "Filter" "Void Transactions")
+                                        "Void Transactions" (cons "Filter" "Void Transactions")
+                                        "Account Substring" (cons "Filter" "Account Name Filter")
+                                        ))
                        (name-match (member name new-names-list)))
 
-                      (if name-match 
-                        (let ((new-name (cadr name-match)))
-                             (lookup-option section new-name))
-                        #f))))
+                  (and name-match
+                       (let ((new-section (car (cadr name-match)))
+                             (new-name (cdr (cadr name-match))))
+                         ;; compare if new-section name exists.
+                         (if new-section
+                             ;; if so, if it's different to current section name
+                             ;; then try new section name
+                             (and (not (string=? new-section section))
+                                  (lookup-option new-section new-name))
+                             ;; else reuse section-name with new-name
+                             (lookup-option section new-name)))))))
           #f)))
 
   (define (option-changed section name)
@@ -1742,6 +1764,16 @@
        new-option
        (lambda () (option-changed section name)))))
 
+  (define (unregister-option section name)
+    (let* ((section-hash (hash-ref option-hash section)))
+      (if (and section-hash
+               (hash-ref section-hash name))
+          (begin
+            (hash-remove! section-hash name)
+            (if (zero? (hash-count (const #t) section-hash))
+                (hash-remove! option-hash section)))
+          (gnc:error "options:unregister-option: no such option\n"))))
+
 ;   Call (thunk option) for each option in the database
   (define (options-for-each thunk)
     (define (section-for-each section-hash thunk)
@@ -1877,6 +1909,7 @@
     (case key
       ((lookup) lookup-option)
       ((register-option) register-option)
+      ((unregister-option) unregister-option)
       ((register-callback) register-callback)
       ((unregister-callback-id) unregister-callback-id)
       ((for-each) options-for-each)
@@ -1917,6 +1950,9 @@
       ((options 'lookup) section name)
       #f))
 
+(define (gnc:unregister-option options section name)
+  ((options 'unregister-option) section name))
+
 (define (gnc:generate-restore-forms options options-string)
   ((options 'generate-restore-forms) options-string))
 
@@ -1965,6 +2001,64 @@
                                   (gnc:option-value src-option)))))
     src-options)))
 
+(define* (gnc:render-options-changed options #:optional plaintext?)
+  ;;
+  ;; options -> string
+  ;;
+  ;; this function will generate an string of options that were changed by the user.
+  ;; by default, it produces an html string.
+  ;; the optional plaintext? = #t will ensure the output is suitable for console output
+  ;; omitting all html elements, and is expected to be used for unit tests only.
+  ;;
+  (let ((row-contents '()))
+    (define (disp d)
+      ;; this function will intelligently display the option value. the option-value is subject to various tests
+      ;; the or clause below will test for boolean, null, list, and pairs. each will trigger a custom function
+      ;; returning a string. the pair option is handled differently because its car will define the data type
+      ;; for its cdr which is either a symbol, time64 number, percent or pixels. if the option does not satisfy
+      ;; any of the above, the function attempts to pass it as a parameter to gnc-commodity-get-mnemonic, or
+      ;; xaccAccountGetName, or gnc-budget-get-name; success leads to application of these functions, failure
+      ;; then leads to a generic stringify function which will handle symbol/string/other types.
+      (define (try thunk arg)
+        ;; this helper function will attempt to run thunk with arg as a parameter. we will catch any 
+        ;; 'wrong-type-arg exception, and return the #f value to the or evaluator below.
+        (catch 'wrong-type-arg
+          (lambda () (thunk arg))
+          (lambda (k . args) #f)))
+      (or (and (boolean? d) (if d (_ "Enabled") (_ "Disabled")))
+          (and (null? d) "null")
+          (and (list? d) (string-join (map disp d) ", "))
+          (and (pair? d) (string-append
+                          (disp (car d)) " . "
+                          (case (car d)
+                            ((relative) (symbol->string (cdr d)))
+                            ((absolute) (qof-print-date (cdr d)))
+                            ((pixels percent) (number->string (cdr d)))
+                            (else (format #f "unknown car of pair, cannot determine format for ~A" (cdr d))))))
+          (try gnc-commodity-get-mnemonic d)
+          (try xaccAccountGetName d)
+          (try gnc-budget-get-name d)
+          (format #f "~A" d)))
+    (define (disp-option-if-changed option)
+      ;; this function is called by gnc:options-for-each on each option, and will test whether default value
+      ;; has been changed and the option is not hidden, and display it using (disp val) as above.
+      (let* ((section (gnc:option-section option))
+             (name (gnc:option-name option))
+             (default-value (gnc:option-default-value option))
+             (value (gnc:option-value option))
+             (return-string (string-append (if plaintext? "" "<b>")
+                                           section " / " name
+                                           (if plaintext? "" "</b>")
+                                           ": "
+                                           (disp value))))
+        (if (not (or (equal? default-value value)
+                     (char=? (string-ref section 0) #\_)))
+            (set! row-contents (cons return-string row-contents)))))
+    (gnc:options-for-each disp-option-if-changed options)
+    (string-append (string-join (reverse row-contents)
+                                (if plaintext? "\n" "<br />\n"))
+                   (if plaintext? "\n\n" "<br />\n<br />\n"))))
+
 (define (gnc:send-options db_handle options)
   (gnc:options-for-each
    (lambda (option)
@@ -2023,3 +2117,11 @@
       )))
   (gnc:options-make-end-date! options pagename name-to
                               (string-append sort-tag "b") info-to))
+
+(define (gnc:option-make-internal! options section name)
+  ;; this function will hide the option specified
+  ;; the option functionality is unchanged
+  (let ((opt (gnc:lookup-option options section name)))
+    (if opt
+        (vector-set! opt 3 'internal)
+        (gnc:error "gnc:option-make-internal! cannot find " section " / " name))))
