@@ -132,15 +132,13 @@ setup_memory (Fixture* fixture, gconstpointer pData)
     xaccAccountSetCommodity (acct1, currency);
 
     auto frame = qof_instance_get_slots (QOF_INSTANCE (acct1));
-    frame->set ("int64-val", new KvpValue (INT64_C (100)));
-    frame->set ("double-val", new KvpValue (3.14159));
-    frame->set ("numeric-val", new KvpValue (gnc_numeric_zero ()));
-
-    frame->set ("timespec-val", new KvpValue (timespec_now ()));
-
-    frame->set ("string-val", new KvpValue ("abcdefghijklmnop"));
+    frame->set ({"int64-val"}, new KvpValue (INT64_C (100)));
+    frame->set ({"double-val"}, new KvpValue (3.14159));
+    frame->set ({"numeric-val"}, new KvpValue (gnc_numeric_zero ()));
+    frame->set ({"timespec-val"}, new KvpValue (timespec_now ()));
+    frame->set ({"string-val"}, new KvpValue ("abcdefghijklmnop"));
     auto guid = qof_instance_get_guid (QOF_INSTANCE (acct1));
-    frame->set ("guid-val", new KvpValue (const_cast<GncGUID*> (guid_copy (
+    frame->set ({"guid-val"}, new KvpValue (const_cast<GncGUID*> (guid_copy (
             guid))));
 
     gnc_account_append_child (root, acct1);
