@@ -56,12 +56,19 @@ add_gnc_num (xmlNodePtr node, const gchar* tag, gnc_numeric num)
     xmlAddChild (node, gnc_numeric_to_dom_tree (tag, &num));
 }
 
+static void
+add_time64 (xmlNodePtr node, const gchar * tag, time64 time, gboolean always)
+{
+    if (always || time)
+        xmlAddChild (node, time64_to_dom_tree (tag, time));
+}
+
 static void
 add_timespec (xmlNodePtr node, const gchar* tag, Timespec tms, gboolean always)
 {
-    if (always || ! ((tms.tv_sec == 0) && (tms.tv_nsec == 0)))
+    if (always || tms.tv_sec)
     {
-        xmlAddChild (node, timespec_to_dom_tree (tag, &tms));
+        xmlAddChild (node, time64_to_dom_tree (tag, tms.tv_sec));
     }
 }
 
@@ -172,10 +179,10 @@ gnc_transaction_dom_tree_create (Transaction* trn)
     }
     g_free (str);
 
-    add_timespec (ret, "trn:date-posted", xaccTransRetDatePostedTS (trn), TRUE);
+    add_time64 (ret, "trn:date-posted", xaccTransRetDatePosted (trn), TRUE);
 
-    add_timespec (ret, "trn:date-entered",
-                  xaccTransRetDateEnteredTS (trn), TRUE);
+    add_time64 (ret, "trn:date-entered",
+                  xaccTransRetDateEntered (trn), TRUE);
 
     str = g_strdup (xaccTransGetDescription (trn));
     if (str)
@@ -275,13 +282,9 @@ static gboolean
 spl_reconcile_date_handler (xmlNodePtr node, gpointer data)
 {
     struct split_pdata* pdata = static_cast<decltype (pdata)> (data);
-    Timespec ts;
-
-    ts = dom_tree_to_timespec (node);
-    if (!dom_tree_valid_timespec (&ts, node->name)) return FALSE;
-
-    xaccSplitSetDateReconciledTS (pdata->split, &ts);
-
+    time64 time  = dom_tree_to_time64 (node);
+    if (!dom_tree_valid_time64 (time, node->name)) return FALSE;
+    xaccSplitSetDateReconciledSecs (pdata->split, time);
     return TRUE;
 }
 
@@ -430,18 +433,24 @@ set_tran_string (xmlNodePtr node, Transaction* trn,
     return TRUE;
 }
 
+static gboolean
+set_tran_time64 (xmlNodePtr node, Transaction * trn,
+        void (*func) (Transaction *, time64))
+{
+    time64 time = dom_tree_to_time64 (node);
+    if (!dom_tree_valid_time64 (time, node->name)) return FALSE;
+    func (trn, time);
+    return TRUE;
+}
+
 static inline gboolean
 set_tran_date (xmlNodePtr node, Transaction* trn,
                void (*func) (Transaction* trn, const Timespec* tm))
 {
-    Timespec tm;
-
-    tm = dom_tree_to_timespec (node);
-
-    if (!dom_tree_valid_timespec (&tm, node->name)) return FALSE;
-
-    func (trn, &tm);
-
+    time64 time = dom_tree_to_time64 (node);
+    if (!dom_tree_valid_time64 (time, node->name)) return FALSE;
+    Timespec ts {time, 0};
+    func (trn, &ts);
     return TRUE;
 }
 
@@ -489,7 +498,7 @@ trn_date_posted_handler (xmlNodePtr node, gpointer trans_pdata)
     struct trans_pdata* pdata = static_cast<decltype (pdata)> (trans_pdata);
     Transaction* trn = pdata->trans;
 
-    return set_tran_date (node, trn, xaccTransSetDatePostedTS);
+    return set_tran_time64 (node, trn, xaccTransSetDatePostedSecs);
 }
 
 static gboolean
@@ -498,7 +507,7 @@ trn_date_entered_handler (xmlNodePtr node, gpointer trans_pdata)
     struct trans_pdata* pdata = static_cast<decltype (pdata)> (trans_pdata);
     Transaction* trn = pdata->trans;
 
-    return set_tran_date (node, trn, xaccTransSetDateEnteredTS);
+    return set_tran_time64 (node, trn, xaccTransSetDateEnteredSecs);
 }
 
 static gboolean
